<?php

class VodYearsScreen extends AbstractPreloadedRegularScreen
    implements UserInputHandler
{
    const ID = 'vod_years';

    public static function get_media_url_str()
    {
        return MediaURL::encode(array('screen_id' => self::ID));
    }

    ///////////////////////////////////////////////////////////////////////

    private $vod;

    public function __construct(Vod $vod)
    {
        $this->vod = $vod;

        parent::__construct(self::ID,
            $vod->get_vod_years_folder_views());

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $select_year_action =
            UserInputHandlerRegistry::create_action(
                $this, 'select_years');

        return array
        (
            GUI_EVENT_KEY_ENTER => $select_year_action,
        );
    }

    public function get_handler_id()
    { return self::ID; }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Vod years: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if ($user_input->control_id == 'select_years')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $year_id = $media_url->year_id;
            $caption = $this->vod->get_year_caption($year_id);
            $media_url_str = $this->vod->get_year_media_url_str($year_id);

            return ActionFactory::open_folder($media_url_str, $caption);
        }

        return null;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->vod->folder_entered($media_url, $plugin_cookies);

        $this->vod->ensure_years_loaded($plugin_cookies);

        $year_ids = $this->vod->get_year_ids();

        $items = array();

        foreach ($year_ids as $year_id)
        {
            $caption = $this->vod->get_year_caption($year_id);
            $media_url_str = $this->vod->get_year_media_url_str($year_id);
            $icon_url = $this->vod->get_year_icon_url($year_id);
			///hd_print("year ---> $icon_url");
            $items[] = array
            (
                PluginRegularFolderItem::media_url => $media_url_str,
                PluginRegularFolderItem::caption => $caption,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => $icon_url,
                )
            );
        }

        return $items;
    }

    public function get_archive(MediaURL $media_url)
    {
        return $this->vod->get_archive($media_url);
    }
}

?>
