<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/default_dune_plugin.php';
require_once 'lib/default_archive.php';
require_once 'lib/action_factory.php';
require_once 'lib/control_factory.php';
require_once 'lib/dune_exception.php';
require_once 'lib/utils.php';
require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/vod/vod_list_screen.php';
require_once 'lib/vod/vod_search_screen.php';
require_once 'lib/vod/vod_genres_screen.php';
require_once 'lib/vod/vod_years_screen.php';
require_once 'lib/vod/vod_movie_screen.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/vod/vod_favorites_screen.php';

require_once 'lib/tv/tv_group_list_screen.php';
require_once 'lib/tv/tv_favorites_screen.php';
require_once 'linuxtv_tv_channel_list_screen.php';
require_once 'linuxtv_exception.php';
require_once 'linuxtv_config.php';
require_once 'linuxtv_entry_handler.php';
require_once 'linuxtv_api.php';
require_once 'linuxtv_tv.php';
require_once 'linuxtv_tv_group_list_screen.php';
require_once 'linuxtv_setup_screen.php';
require_once 'linuxtv_vod.php';
require_once 'linuxtv_vod_root_screen.php';
require_once 'linuxtv_vod_list_screen.php';
require_once 'linuxtv_vod_movie_screen.php';

require_once 'lib/list_util.php';
///////////////////////////////////////////////////////////////////////////

class LinuxtvPlugin extends DefaultDunePlugin
{
    private $session;
    private $entry_handler;

    public function __construct()
    {
        $this->session = new LinuxtvApi($this);
        $this->entry_handler = new LinuxtvEntryHandler($this->session);
        $this->tv = new LinuxtvTv($this->session);
        $this->vod = new LinuxtvVod($this->session);

        $tv_folder_views = $this->get_tv_folder_views();
		
	$this->add_screen(new LinuxtvSetupScreen($this->session));

		$this->add_screen(new Linuxtv_TvChannelListScreen($this->tv,
            LinuxtvConfig::GET_TV_CHANNEL_LIST_FOLDER_VIEWS()));
        $this->add_screen(new LinuxtvTvGroupListScreen($this->tv,
            LinuxtvConfig::GET_TV_GROUP_LIST_FOLDER_VIEWS(), $this->session));
        $this->add_screen(new TvFavoritesScreen($this->tv,
            LinuxtvConfig::GET_TV_CHANNEL_LIST_FOLDER_VIEWS()));
            
        $this->add_screen(new LinuxtvVodRootScreen($this->session, $tv_folder_views));

        $this->add_screen(new LinuxtvVodListScreen($this->session, $this->vod));

        $this->add_screen(new LinuxtvVodMovieScreen($this->session, $this->vod));

        $this->add_screen(new VodSeriesListScreen($this->vod));

        $this->add_screen(new VodFavoritesScreen($this->vod));

        $this->add_screen(new VodSearchScreen($this->vod));

        $this->add_screen(new VodGenresScreen($this->vod));
        
        $this->add_screen(new VodYearsScreen($this->vod));

    }

    ///////////////////////////////////////////////////////////////////////

    public function unset_login()
    {
        $this->session->unset_login();
        $this->tv->unload_channels();
        $this->vod->clear_movie_cache();
        $this->vod->clear_genre_cache();
        $this->vod->clear_year_cache();
        DefaultArchive::clear_cache();
    }

    ///////////////////////////////////////////////////////////////////////

    private function get_tv_folder_views()
    {
        return LinuxtvConfig::GET_TV_GROUP_LIST_FOLDER_VIEWS();
    }
	private function get_vod_root_views()
    {
        return LinuxtvConfig::GET_VOD_ROOT_FOLDER_VIEWS();
    }
   
}

///////////////////////////////////////////////////////////////////////////
?>
