<?php

///////////////////////////////////////////////////////////////////////////

require_once 'lib/vod/vod_list_screen.php';
require_once 'linuxtv_movie.php';
require_once 'linuxtv_check_bin.php';

class LinuxtvVodListScreen extends VodListScreen

{
    public static function get_media_url_str($page_name, $arg = null)
    {
        $arr['screen_id'] = self::ID;
        $arr['page_name'] = $page_name;
        if ($page_name === 'search')
            $arr['pattern'] = $arg;
        else if ($page_name === 'genres')
            $arr['genre_id'] = $arg;
        else if ($page_name === 'years')
            $arr['year_id'] = $arg;   
        else if ($page_name === 'collection')
            $arr['movie_id'] = $arg;
        else if ($page_name === 'seasons')
            $arr['movie_id'] = $arg;
        return MediaURL::encode($arr);
    }

    ///////////////////////////////////////////////////////////////////////

    private $session;
	private $vod;
	
    public function __construct($session, Vod $vod)
    {
        parent::__construct($vod);
		$this->vod = $vod;
        $this->session = $session;
    }

    ///////////////////////////////////////////////////////////////////////
	public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $actions = array();

        if ($this->vod->is_movie_page_supported())
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::open_folder();
        else
            $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::vod_play();

        if ($this->vod->is_favorites_supported())
        {
            $add_favorite_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'add_favorite');
            $add_favorite_action['caption'] = 'Избранное';
			
            $popup_menu_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'popup_menu');

            $actions[GUI_EVENT_KEY_D_BLUE] = $add_favorite_action;
            $actions[GUI_EVENT_KEY_POPUP_MENU] = $popup_menu_action;
        }
		/////////////////////////
		$actions[GUI_EVENT_KEY_INFO] =
            UserInputHandlerRegistry::create_action(
                $this, 'info');
		
		//////////////////
        return $actions;
    }
    ///////////////////////////////////////////////////////////////////////
    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        $ip_path = isset($plugin_cookies->ip_path) ? 
			$plugin_cookies->ip_path : '';
		$smb_user = isset($plugin_cookies->smb_user) ? 
			$plugin_cookies->smb_user : 'guest';
		$smb_pass = isset($plugin_cookies->smb_pass) ? 
			$plugin_cookies->smb_pass : 'guest';
		#hd_print('Vod favorites: handle_user_input:');
        foreach ($user_input as $key => $value)
            #hd_print("  $key => $value");

        if ($user_input->control_id == 'popup_menu')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $movie_id = $media_url->movie_id;
			
			//////
			$bgr_rs = DuneSystem::$properties['tmp_dir_path'] . '/background_rec_stop';
			if (file_exists($bgr_rs)) {
			$name = trim(file_get_contents($bgr_rs));
			$dd = "/tmp/".$name."_linuxtvrec.sh";
			if (!file_exists($dd))
				unlink($bgr_rs);
			}
			///////

            $is_favorite = $this->vod->is_favorite_movie_id($movie_id);
            $add_favorite_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'add_favorite');
            $caption = 'Добавить в Избранное';
			$film_info_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'info');
            $info_caption = 'Информация о фильме [INFO]';
			///////////////////////////////////////
			/* $background_rec_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'background_rec');
            $background_rec_caption = 'Фоновая Запись фильма';
			$background_stoprec_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'background_stoprec');
            $background_stoprec_caption = 'Остановить Запись'; */
			///////////////////////////////////////
            $menu_items[] = array(
                GuiMenuItemDef::caption => $caption,
                GuiMenuItemDef::action => $add_favorite_action,
				GuiMenuItemDef::icon_url => 'plugin_file://icons/small/fav.aai');
			$menu_items[] = array(
                GuiMenuItemDef::caption => $info_caption,
                GuiMenuItemDef::action => $film_info_action,
				GuiMenuItemDef::icon_url => 'plugin_file://icons/small/info.aai');
			///////
			/* $menu_items [] =  array( 
				GuiMenuItemDef::is_separator => true,);	
			$menu_items[] = array(
                GuiMenuItemDef::caption => $background_rec_caption,
                GuiMenuItemDef::action => $background_rec_action);
			if (file_exists($bgr_rs)) {
			$menu_items[] = array(
                GuiMenuItemDef::caption => $background_stoprec_caption,
                GuiMenuItemDef::action => $background_stoprec_action);} */
			////////

            return ActionFactory::show_popup_menu($menu_items);
        }
        else if ($user_input->control_id == 'add_favorite')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $movie_id = $media_url->movie_id;

            $is_favorite = $this->vod->is_favorite_movie_id($movie_id);
            if ($is_favorite)
            {
                return ActionFactory::show_title_dialog(
                    'Фильм уже находится в избранном');
            }
            else
            {
                $this->vod->add_favorite_movie($movie_id, $plugin_cookies);

                return ActionFactory::show_title_dialog(
                    'Фильм добавлен в избранное');
            }
        }
		//////////////////////
		elseif ($user_input->control_id == 'info')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            

            $movies = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
			#print_r($movies);
            $title = $movies->name;
			$movie_id = $movies->id;
			$lenght = $movies->length_min;
			if($lenght == -1)
			{
				$lenght = 'Неизвестно';
			}
			$text = $movies->description;
			$newtext_1 = wordwrap($text, 100, "\n");
			$newtext = self::cropStr($newtext_1, 35);
			$defs = array();
			$texts = explode("\n", $newtext);
			$texts = array_values($texts);
			ControlFactory::add_label($defs, "ID фильма: ", $movie_id);
			ControlFactory::add_label($defs, "Длительность: ", $lenght . ' мин.');
			foreach($texts as $text)
			{
				
				ControlFactory::add_label($defs, "", $text);
			}
			ControlFactory::add_close_dialog_button($defs, 'OK', 150);

			return ActionFactory::show_dialog($title, $defs);
        }
		//////////////////////
		else if ($user_input->control_id === 'background_rec')
		{
		if (!isset($user_input->selected_media_url))
        return null;
		$media_url = MediaURL::decode($user_input->selected_media_url);
                $movie_id = $media_url->movie_id;
		$movies = $this->vod->get_loaded_movie($media_url->movie_id, $plugin_cookies);
		$title = $movies->name;
		$ru_title = self::translit_to_rus($title);
		#hd_print("ru_title----->$title");
		$rec_path = self::get_rec_path($plugin_cookies);
		#hd_print("rec_path----->$rec_path");
		$streaming_url = $this->vod->get_vod_stream_url($movie_id, &$plugin_cookies);
		#hd_print("URL_REC----->$streaming_url");
		$rec_name = $ru_title;
		$streaming_url = str_replace('http://ts://127.0.0.1:1000/cgi-bin/arch?', '', $streaming_url);
		$ptl = "http";
		$rec_script = '/tmp/arch/rec';
		CHECK::check_for_arch();
		$cmd_rec = "$rec_script --$ptl \"$streaming_url\" \"$rec_name\" \"$rec_path\"";
		$free = "$rec_path";
		if (!file_exists($rec_path))
		return ActionFactory::show_title_dialog("Накопитель для записи не найден!!! Подключите к плееру накопитель.");
		if (preg_match('/\/D\//',$rec_path)){
		$bytes = disk_free_space ('/D/');
		#hd_print("bytes------------->$bytes");
		$si_prefix = array( 'B', 'KB', 'MB', 'GB', 'TB', 'EB', 'ZB', 'YB' );
		$base = 1024;
		$class = min((int)log($bytes , $base) , count($si_prefix) - 1);
		$free = sprintf('%1.2f' , $bytes / pow($base,$class)) . ' ' . $si_prefix[$class];
		if ($bytes < 1000000000)
		return ActionFactory::show_title_dialog("Свободного места на диске меньше 1ГБ ($free). Запись не началась!!!");
		}
		$rec_file = DuneSystem::$properties['tmp_dir_path'] . '/background_rec_stop';
		$date_count = fopen($rec_file,"w");
		if (!$date_count)
		return ActionFactory::show_title_dialog("Не могу записать в tmp Что-то здесь не так!!!");
		fwrite($date_count, $rec_name);
		@fclose($date_count);
		shell_exec($cmd_rec);
		ControlFactory::add_label($defs, "Запись фильма:", "$title");
		ControlFactory::add_label($defs, "Свободно на диске:", "$free");
		ControlFactory::add_label($defs, "", "Вы можете в любой момент остановить запись!");
		$do_br_apply = UserInputHandlerRegistry::create_action($this, 'new_br_apply');
        ControlFactory::add_custom_close_dialog_and_apply_buffon($defs,
		'_do_br_apply', 'ОК', 250, $do_br_apply);
		return ActionFactory::show_dialog('Запись фильма', $defs, 1);
		}
		else if ($user_input->control_id === 'background_stoprec')///////////////////////////////////////
		{
		if (!isset($user_input->selected_media_url))
                return null;
		$rec_file = DuneSystem::$properties['tmp_dir_path'] . '/background_rec_stop';
		if (!file_exists($rec_file))
		return ActionFactory::show_title_dialog("Активная фоновая запись не найдена.");
		$background_rec_stop = trim(file_get_contents($rec_file));
		unlink($rec_file);
		$cmd_stoprec = '/tmp/' .$background_rec_stop.'_linuxtvrec.sh';
		shell_exec($cmd_stoprec);
		$perform_new_action = UserInputHandlerRegistry::create_action(
                    $this, 'dialog_rec_stop');
		return ActionFactory::invalidate_folders(array('vod_list'), $perform_new_action);}
		else if ($user_input->control_id === 'dialog_rec_stop')	{
		return ActionFactory::show_title_dialog("Запись остановлена.");}
		//////////////
        return null;
    }
	///////////////////////////////////////////////////////////////////////
    private function get_page_for_ndx($ndx, $page_size)
    {
        return intval($ndx / $page_size) + 1;
    }

    protected function get_short_movie_range(MediaURL $media_url, $from_ndx,
        &$plugin_cookies)
    {
        #hd_print("####### get_short_movie_range");
        $nums = 24;
        $page = $this->get_page_for_ndx($from_ndx, $nums);

        if ($media_url->page_name === 'last')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, null, '>'.$lastyear, null, null);
        else if ($media_url->page_name === 'all')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, null, null, null, null);
        else if ($media_url->page_name === 'search')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, $media_url->pattern, null, null, "1,5,6");
        else if ($media_url->page_name === 'genres')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, $media_url->genre_id, null, null, null, null, null);
	else if ($media_url->page_name === 'years')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, null, $media_url->year_id, null, null);            
        else if ($media_url->page_name === 'serials')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, null, null, null, 6);
        else if ($media_url->page_name === 'collections')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, null, null, null, 5);
        else if ($media_url->page_name === 'collection')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, null, null, null, null, $media_url->movie_id);
        else if ($media_url->page_name === 'seasons')
            $doc = $this->session->api_get_list_movie($page, $nums, 0, null, null, null, null, null, null, $media_url->movie_id);
        else
            throw new Exception('Vod list: invalid page name.');

        $cnt = $doc->options->count;

		if ($doc->groups->item->title == "No video subscribe")
            return new ShortMovieRange(0, 0);

        if (empty($cnt))
            throw new Exception('Invalid data returned from server');
        $total = intval($cnt);
        if ($total === 0)
            return new ShortMovieRange(0, 0);

        $from_ndx = (intval($doc->options->page) - 1) * $nums;

        $movies = array();
        foreach ($doc->groups->item as $row)
        {
            $icon_url = strval($row->pic);
            $movies[] = new LinuxtvShortMovie(
                intval($row->id), strval($row->title), $icon_url, intval($row->type));
        }

        return new ShortMovieRange($from_ndx, $total, $movies);
    }
	public function get_folder_range(MediaURL $media_url, $from_ndx, &$plugin_cookies)
    {
        $movie_range = $this->get_short_movie_range(
            $media_url, $from_ndx, $plugin_cookies);

        $total = intval($movie_range->total);
        if ($total <= 0)
            return HD::create_regular_folder_range(array());

        $items = array();
        foreach ($movie_range->short_movies as $movie)
        {
            $items[] = array
            (
                PluginRegularFolderItem::media_url =>
                    LinuxtvVodMovieScreen::get_media_url_str($movie->id),
                PluginRegularFolderItem::caption => $movie->name,
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path => $movie->poster_url,
                )
            );

            $this->vod->set_cached_short_movie(
                new LinuxtvShortMovie($movie->id, $movie->name, $movie->poster_url, $movie->movie_type));
        }

        return HD::create_regular_folder_range(
            $items, $movie_range->from_ndx, $total);
    }
	private static function get_rec_path(&$plugin_cookies) {
		$recdata = isset($plugin_cookies->recdata) ? 
		$plugin_cookies->recdata : '/D';
		$recdata_dir = isset($plugin_cookies->recdata_dir) ? 
		$plugin_cookies->recdata_dir : '/';
		if ($recdata !== '1')
		$rec_path = $recdata.$recdata_dir;
		elseif ($recdata == '1') {
			$recdata_smb_user = isset($plugin_cookies->recdata_smb_user) ? 
			$plugin_cookies->recdata_smb_user : 'guest';
			$recdata_smb_pass = isset($plugin_cookies->recdata_smb_pass) ? 
			$plugin_cookies->recdata_smb_pass : 'guest';
			$recdata_ip_path = isset($plugin_cookies->recdata_ip_path) ? 
			$plugin_cookies->recdata_ip_path : '';
			if ($recdata_ip_path == '')
				$rec_path = '/D/';
			else
				$rec_path = HD::get_mount_smb_path($recdata_ip_path, $recdata_smb_user, $recdata_smb_pass, 'recdata_path');
		}
		return $rec_path;
	}
	private static function translit_to_rus($str) {
	$str = preg_replace('/[-`~!#$%^&*()_=+\\\\|\\/\\[\\]{};:"\',<>?]+/','',$str);
    return str_replace(' ', '_', $str);
	}

	private static function cropStr($text, $max_words)
	{
    $words = explode(' ',$text);
    if(count($words) > $max_words && $max_words > 0)
    {
    $text = implode(' ',array_slice($words, 0, $max_words)).'...';
    }
    return $text;
	}
	
}

///////////////////////////////////////////////////////////////////////////
?>
