﻿<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/screen.php';
require_once 'lib/vod/vod.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/vod/vod_movie_screen.php';

class LinuxtvVodMovieScreen extends VodMovieScreen
{

    private $session;
	private $vod;

    public function __construct($session, Vod $vod)
    {
        parent::__construct($vod);

        $this->session = $session;
		$this->vod = $vod;
    }
    
    public static function get_media_url_str($movie_id)
    {
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'movie_id' => $movie_id));
    }

    ///////////////////////////////////////////////////////////////////////
	
	public function get_folder_view(MediaURL $media_url, &$plugin_cookies)
    {	
		// сначала загрузим фильм в кэш
		$folder_view = parent::get_folder_view($media_url, $plugin_cookies);
		$movie = $this->vod->get_cached_movie($media_url->movie_id);
		
		$folder_view[PluginFolderView::data][PluginMovieFolderView::left_button_action] = 
				UserInputHandlerRegistry::create_action(
				$this, 'check_protected',
				array('movie_id' => $media_url->movie_id));

		if($movie != null && $movie->seasons == 1)
			$folder_view[PluginFolderView::data][PluginMovieFolderView::left_button_caption] = 'Сезоны';
		elseif($movie != null && $movie->movie_type == 6)
			$folder_view[PluginFolderView::data][PluginMovieFolderView::left_button_caption] = 'Серии';
		elseif($movie != null && $movie->movie_type == 5)
			$folder_view[PluginFolderView::data][PluginMovieFolderView::left_button_caption] = 'Фильмы';
		elseif($movie != null && $movie->movie_type == 3)
			$folder_view[PluginFolderView::data][PluginMovieFolderView::left_button_caption] = 'Серии';
		
		return $folder_view;
    }

    ///////////////////////////////////////////////////////////////////////

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Movie: handle_user_input:');
        foreach ($user_input as $key => $value)
#            hd_print("  $key => $value");

        if ($user_input->control_id == 'check_protected')
        {
		hd_print("Check protected");
		$movie_id = $user_input->movie_id;
		$movie = $this->vod->get_cached_movie($movie_id);
		
		// коллекция
		if($movie != null && $movie->movie_type == 5)
			return ActionFactory::open_folder(LinuxtvVodListScreen::get_media_url_str('collection', $movie->id), 'Фильмы');

		// сериал с сезонами
		if($movie != null && $movie->movie_type == 6 && $movie->seasons == 1)
			return ActionFactory::open_folder(LinuxtvVodListScreen::get_media_url_str('seasons', $movie->id), 'Сезоны');
			
		// сезон с сериями
		if($movie != null && $movie->movie_type == 3)
		{
			$check_action = $this->check($movie->series_list[0]->id, $plugin_cookies);
			if($check_action !== null)
				return $check_action;

			return ActionFactory::open_folder(VodSeriesListScreen::get_media_url_str($movie->id), 'Серии');
		}
		
		// сериал или сезон или фильм с сериями
		if($movie != null && ($movie->movie_type == 1 || $movie->movie_type == 6 || $movie->movie_type == 3) && isset($movie->series_list) && is_array($movie->series_list) && count($movie->series_list) > 1)
		{
			$check_action = $this->check($movie->series_list[0]->id, $plugin_cookies);
			if($check_action !== null)
				return $check_action;

			return ActionFactory::open_folder(VodSeriesListScreen::get_media_url_str($movie->id), $movie->name);
		}

		$check_action = $this->check($movie_id, $plugin_cookies);
		if($check_action !== null)
			return $check_action;
			
		return ActionFactory::vod_play();
	}
	elseif ($user_input->control_id == 'apply_pcode')
	{
		$movie_id = $user_input->movie_id;
		$movie = $this->vod->get_cached_movie($movie_id);
		$movie->protect_code = $user_input->protect_code;
		$this->vod->set_cached_movie($movie);
		return ActionFactory::vod_play();
	}

        return parent::handle_user_input($user_input, $plugin_cookies);
    }
	
	private function check($movie_id, &$plugin_cookies)
	{
		try { $this->vod->get_vod_stream_url($movie_id, $plugin_cookies); }
		catch(Exception $e)
		{
			if($e instanceof LinuxtvException)
				$ecode = $e->getMessage();
			elseif($e->getPrevious())
				$ecode = $e->getPrevious()->getMessage();
			else
				$ecode = $e->getMessage();

			hd_print("VOD url error code: $ecode.");
			if($ecode == S_URL_PROTECTED)
			{
				$defs = array();
				ControlFactory::add_text_field($defs,
					$this, null,
					'protect_code', 'Пароль для взрослых',
					'', true, true, false, false, 300);
				ControlFactory::add_close_dialog_and_apply_button($defs,
					$this, array('movie_id' => $movie_id),
					'apply_pcode', 'OK', 200);

				return ActionFactory::show_dialog(null, $defs, true);
			}
			else if($ecode == S_URL_NOT_FOUND)
			{
				// return alert
				hd_print("no option in package");
				return ActionFactory::show_error(false, 'Просмотр невозможен', array('Данная услуга не входит в пакет'));
			}
			else if($ecode == S_NO_SUBSCRIPTIONS)
			{
				// return alert
				hd_print("no subscriptions");
				return ActionFactory::show_error(false, 'Просмотр невозможен', array('Данная услуга не входит в пакет'));
			}
			else if($ecode == S_SUBSCRIPTION_TO_PAUSE)
			{
				// return alert
				hd_print("subscription paused");
				return ActionFactory::show_error(false, 'Просмотр невозможен', array('Данная услуга не входит в пакет'));
			}
			else
			{
				// return alert
				hd_print("unknown error");
				return ActionFactory::show_error(false, 'Просмотр невозможен', array($ecode));
			}
		}
		return null;
	}
}

///////////////////////////////////////////////////////////////////////////
?>
